<?php defined("SYSPATH") or die("No direct script access.");
/**
 * Gallery - a web based photo album viewer and editor
 * Copyright (C) 2000-2012 Bharat Mediratta
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
 */
class Admin_Artfu_Controller extends Controller {

  public function index() {
    print $this->_get_view();
  }

  public function _get_view() {
    $v = new Admin_View("admin.html");
    $v->content = new View("admin_artfu_form.html");
    $v->content->artfu_form = $this->get_form();
    print $v;
  }

  private function get_form() {
    $to_item_id = module::get_var("artfu", "to_item_id");
    $to_incr = module::get_var("artfu", "to_incr");
    $to_prefix = module::get_var("artfu", "to_prefix");
    $to_prefix_val = module::get_var("artfu", "to_prefix_val");
    $to_suffix = module::get_var("artfu", "to_suffix");
    $to_suffix_val = module::get_var("artfu", "to_suffix_val");
    $inc_url = module::get_var("artfu", "inc_url");
    $inc_title = module::get_var("artfu", "inc_title");
    $incr_start = module::get_var("artfu", "incr_start");
    $incr_length = module::get_var("artfu", "incr_length");
    $pad_zero = module::get_var("artfu", "pad_zero");
    if(!$incr_start){ $incr_start = 1; }
    if(!$incr_length){ $incr_length = 5; }
    if(!$to_prefix_val){ $to_prefix_val = "prefix"; }
    if(!$to_suffix_val){ $to_suffix_val = "suffix"; }

    $form = new Forge("admin/artfu/save", "", "post", array("id" => "g-artfu-form"));
    $group1 = $form->group("g_artfu_form1")->label(t("Automatically rename uploaded items to:"));

    $group1->checkbox("to_item_id")
      ->label(t("the item's ID#"))
      ->class("g-unique g-button-text")
      ->checked($to_item_id);
    $group1->checkbox("to_incr")
      ->label(t("an incremented value"))
      ->class("g-unique")
      ->checked($to_incr);
    $group1->input("incr_start")
      ->rules("valid_digit")
      ->error_messages("valid_digit", t("Must be digits only"))
      ->label(t("start counts at:"))
      ->value($incr_start);
    $group1->checkbox("pad_zero")
      ->label(t("Pad with zero's?"))
      ->checked($pad_zero);
    $group1->input("incr_length")
      ->rules("valid_digit")
      ->error_messages("valid_digit", t("Must be digits only"))
      ->label(t("How many digits long?"))
      ->value($incr_length);
    $group1->checkbox("to_prefix")
      ->label(t("include a prefix of:"))
      ->checked($to_prefix);
    $group1->input("text")
      ->value(t("Example:  'prefix' would generate: prefix1, prefix2, prefix3 ... prefix99"))
      ->class('g-info')
      ->disabled(true);
    $group1->input("to_prefix_val")
      ->rules('required|valid_alpha_dash')
      ->error_messages("required", t("You must enter a prefix"))
      ->error_messages("valid_alpha_dash", t("Must only be alpha/numeric/dashes"))
      ->value($to_prefix_val);
    $group1->checkbox("to_suffix")
      ->label(t("include a suffix of:"))
      ->checked($to_suffix);
    $group1->input("text2")
      ->value(t("Example:  'suffix' would generate: 1suffix, 2suffix, 3suffix ... 99suffix"))
      ->class('g-info')
      ->disabled(true);
    $group1->input("to_suffix_val")
      ->rules('required|valid_alpha_dash')
      ->error_messages("required", t("You must enter a suffix"))
      ->error_messages("valid_alpha_dash", t("Must only be alpha/numeric/dashes"))
      ->value($to_suffix_val);
    $group1->checkbox("inc_url")
      ->label(t("also rename the URL"))
      ->checked($inc_url);
    $group1->checkbox("inc_title")
      ->label(t("also rename the Title"))
      ->checked($inc_title);
    
    $form->submit("submit")->value(t("Save"))->class("submit ui-state-default ui-corner-all");
    return $form;
  }
  public function save() {
    $form = $this->get_form();
    $valid = $form->validate();
    if($valid) {
      $to_prefix_val = preg_replace("/\s+/","",$form->g_artfu_form1->to_prefix_val->value);
      $to_suffix_val = preg_replace("/\s+/","",$form->g_artfu_form1->to_suffix_val->value);
      module::set_var("artfu", "to_item_id", $form->g_artfu_form1->to_item_id->value);
      module::set_var("artfu", "to_incr", $form->g_artfu_form1->to_incr->value);
      module::set_var("artfu", "to_prefix", $form->g_artfu_form1->to_prefix->value);
      module::set_var("artfu", "to_suffix", $form->g_artfu_form1->to_suffix->value);
      module::set_var("artfu", "to_prefix_val", $to_prefix_val);
      module::set_var("artfu", "to_suffix_val", $to_suffix_val);
      module::set_var("artfu", "inc_url", $form->g_artfu_form1->inc_url->value);
      module::set_var("artfu", "inc_title", $form->g_artfu_form1->inc_title->value);
      module::set_var("artfu", "incr_start", $form->g_artfu_form1->incr_start->value);
      module::set_var("artfu", "pad_zero", $form->g_artfu_form1->pad_zero->value);
      module::set_var("artfu", "incr_length", $form->g_artfu_form1->incr_length->value);
      message::success(t("ARTFU Settings Saved..."));
      site_status::clear("artfu_configuration");
      url::redirect("admin/artfu");
    } else {
      print $this->_get_view();
    }
  }
}
